@@ -53,12 +53,59 @@ Image <- R6::R6Class("Image",
         print=function() {
             self$.render()
         },
-        .render=function(...) {
+        saveAs=function(path, ...) {
+
             if ( ! is.character(private$.renderFun))
-                return()
+                stop('no render function', call.=FALSE)
+
+            if (endsWith(tolower(path), '.pdf')) {
+                cairo_pdf(
+                    file=path,
+                    width=private$.width/72,
+                    height=private$.height/72)
+            } else if (endsWith(tolower(path), '.svg')) {
+                svg(
+                    file=path,
+                    width=private$.width/72,
+                    height=private$.height/72)
+            } else if (endsWith(tolower(path), '.eps')) {
+                cairo_ps(
+                    file=path,
+                    width=private$.width/72,
+                    height=private$.height/72)
+            } else if (endsWith(tolower(path), '.png')) {
+
+                multip <- 144 / 72
+                grType <- 'cairo'
+                if (Sys.info()['sysname'] == 'Windows')
+                    grType <- 'windows'
+
+                grDevices::png(type=grType,
+                               filename=path,
+                               width=private$.width * multip,
+                               height=private$.height * multip,
+                               bg='transparent',
+                               res=72 * multip)
+            } else {
+                reject('unrecognised format')
+            }
+
+            on.exit(grDevices::dev.off())
 
             self$analysis$.render(funName=private$.renderFun, image=self, ...)
         },
+        .render=function(...) {
+            if ( ! is.character(private$.renderFun))
+                return(FALSE)
+
+            self$analysis$.render(funName=private$.renderFun, image=self, ...)
+        },
+        .createImages=function(...) {
+            if ( ! is.character(private$.renderFun))
+                return(FALSE)
+
+            self$analysis$.createImage(funName=private$.renderFun, image=self, ...)
+        },
         .setPath=function(path) {
             private$.path <- path
         },
@@ -85,6 +132,12 @@ Image <- R6::R6Class("Image",
                 path=path)
 
             result <- super$asProtoBuf(incAsText=incAsText, status=status)
+
+            if (status == jamovi.coms.AnalysisStatus$ANALYSIS_COMPLETE &&
+                ( ! is.null(self$state)) &&
+                path == '')
+                    result$status <- jamovi.coms.AnalysisStatus$ANALYSIS_RENDERING
+
             result$image <- image
             result
         },
@@ -110,9 +163,18 @@ Image <- R6::R6Class("Image",
 
             private$.width <- image$width
             private$.height <- image$height
-            if (image$path == '')
+            if (image$path == '' || 'theme' %in% oChanges)
                 private$.path <- NULL
             else
                 private$.path <- image$path
         })
 )
+
+#' @export
+#' @importFrom utils .DollarNames
+.DollarNames.Image <- function(x, pattern = "") {
+    names <- ls(x, all.names=F, pattern = pattern)
+    retain <- c('saveAs')
+    names <- intersect(names, retain)
+    names
+}
